#include <Arduino.h>
#include "ds1307.h"

boolean ds1307_rtc::getTime(const char *str) {
	int Hour, Min, Sec;
	if (sscanf(str, "%d:%d:%d", &Hour, &Min, &Sec) != 3) return false;
	tm.Hour = Hour;
	tm.Minute = Min;
	tm.Second = Sec;
	return true;
}

boolean ds1307_rtc::getDate(const char *str) {
	char Month[12];
	int Day, Year; uint8_t monthIndex;
	if (sscanf(str, "%s %d %d", Month, &Day, &Year) != 3) return false;
	for (monthIndex = 0; monthIndex < 12; monthIndex++) {
		if (strcmp(Month, monthName[monthIndex]) == 0) break;
	}
	if (monthIndex >= 12) return false;
	tm.Day = Day;
	tm.Month = monthIndex + 1;
	tm.Year = CalendarYrToTm(Year);
	return true;
}

void ds1307_rtc::setRTC() {
	if(getDate(__DATE__)&&getTime(__TIME__)) RTC.write(tm);
}

String ds1307_rtc::readTime() {
	RTC.read(tm);
	String Time = String(tm.Hour) + String(":") + String(tm.Minute) + String(":") + String(tm.Second);
	return Time;
}

String ds1307_rtc::readDate() {
	RTC.read(tm);
	String Date = tmYearToCalendar(tm.Year) + String("-") + tm.Month + String("-") + tm.Day;
	return Date;
}

float ds1307_rtc::readTimeField(uint8_t field) {
	RTC.read(tm);
	switch (field) {
		case 0: return (float)tm.Hour;
		case 1: return (float)tm.Minute;
		case 2: return (float)tm.Second;
	}
}

float ds1307_rtc::readDateField(uint8_t field) {
	RTC.read(tm);
	switch (field) {
		case 0: return (float)tmYearToCalendar(tm.Year);
		case 1: return (float)tm.Month;
		case 2: return (float)tm.Day;
	}
}
